@@ -4,7 +4,7 @@ use warnings;
 
 package Dist::Zilla::Plugin::Test::ReportPrereqs;
 # ABSTRACT: Report on prerequisite versions during automated testing
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 use Dist::Zilla 4 ();
 use File::Slurp qw/read_file write_file/;
@@ -46,7 +46,7 @@ Dist::Zilla::Plugin::Test::ReportPrereqs - Report on prerequisite versions durin
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
@@ -60,9 +60,8 @@ AUTOMATED_TESTING is true, it reports the version of all modules listed in the
 distribution metadata prerequisites (including 'recommends', 'suggests', etc.).
 
 If a MYMETA.json file exists and L<CPAN::Meta> is installed on the testing
-machine, MYMETA.json will be examined for prerequisites as it would include any
-dynamic prerequisites.  Otherwise, a static list of prerequisites is used,
-generated when distribution tarball was built.
+machine, MYMETA.json will be examined for prerequisites in addition, as it
+would include any dynamic prerequisites not set in the distribution metadata.
 
 Versions are reported based on the result of C<parse_version> from
 L<ExtUtils::MakeMaker>, which means prerequisite modules are not actually
@@ -152,10 +151,13 @@ INSERT_MODULE_LIST_HERE
 );
 
 # replace modules with dynamic results from MYMETA.json if we can
-if ( -f "MYMETA.json" && eval { require CPAN::Meta } ) {
+# (hide CPAN::Meta from prereq scanner)
+my $cpan_meta = "CPAN::Meta";
+if ( -f "MYMETA.json" && eval "require $cpan_meta" ) { ## no critic
   if ( my $meta = eval { CPAN::Meta->load_file("MYMETA.json") } ) {
     my $prereqs = $meta->prereqs;
     my %uniq = map {$_ => 1} map { keys %$_ } map { values %$_ } values %$prereqs;
+    $uniq{$_} = 1 for @modules; # don't lose any static ones
     @modules = sort keys %uniq;
   }
 }
